@@ -15,10 +15,48 @@ import barobo._util as _util
 class Linkbot:
   """
   The Linkbot Class
+  =================
 
   Each instance of this class can be used to represent a physical Linkbot. The
   member functions of this class can be used to get data, set motor angles,
   beep the buzzer, scan for button events, and more.  
+
+  Blocking and Non-Blocking Member Functions
+  ==========================================
+
+  The member functions of the Linkbot class which are responsible for moving
+  the joints of the Linkbot can be categorized into two general types of
+  functions; "blocking" functions and "non-blocking" functions. A blocking
+  function is a function that "hangs" until the complete motion is done,
+  whereas a "non-blocking" function returns as soon as the motion begins,
+  but does not wait until it is done. In the Linkbot class, all functions
+  are blocking unless the have the suffix "NB", such as "Linkbot.moveNB()".
+
+  For example, consider the following lines of code::
+    linkbot.move(360, 0, 0)
+    linkbot.setBuzzerFrequency(440)
+  When the above lines of code are executed, the Linkbot will rotate joint 1
+  360 degrees. Once the joint has rotated the full revolution, the buzzer will
+  sound. Now consider the following code::
+    linkbot.moveNB(360, 0, 0)
+    linkbot.setBuzzerFrequency(440)
+  For these lines of code, joint 1 also moves 360 degrees. The difference is 
+  that with these lines of code, the buzzer will begin emitting a tone as soon
+  as the joint begins turning, instead of waiting for the motion to finish.
+  This is because the non-blocking version of move() was used, which returns
+  immediately after the joint begins moving allowing the setBuzzerFrequency() 
+  function to execute as the joint begins moving.
+
+  The L{moveWait()<barobo.linkbot.Linkbot.moveWait>} function can be used to block until non-blocking motion 
+  functions are finished. For instance, the following two blocks of code
+  will accomplish the same task::
+    linkbot.move(360, 0, 0)
+    linkbot.setBuzzerFrequency(440)
+
+    linkbot.moveNB(360, 0, 0)
+    linkbot.moveWait()
+    linkbot.setBuzzerFrequency(440)
+
   """
 
   def __init__(self):
@@ -190,7 +228,7 @@ class Linkbot:
     buf = bytearray([barobo.BaroboCtx.CMD_GETACCEL, 0x03, 0x00])
     response = self.__transactMessage(buf)
     values = barobo._unpack('<3h', response[2:8])
-    return map(lambda x: x/16384.0, values)
+    return list(map(lambda x: x/16384.0, values))
 
   def getBatteryVoltage(self):
     """
@@ -290,7 +328,7 @@ class Linkbot:
     buf = bytearray([barobo.BaroboCtx.CMD_GETMOTORANGLESABS, 3, 0])
     response = self.__transactMessage(buf)
     angles = barobo._unpack('<4f', response[2:18])
-    return map(_util.rad2deg, angles[:3])
+    return list(map(_util.rad2deg, angles[:3]))
 
   def getJointAnglesTime(self):
     """
@@ -305,7 +343,7 @@ class Linkbot:
     millis = barobo._unpack('<L', response[2:6])[0]
     data = barobo._unpack('<4f', response[6:-1])
     rc = [millis/1000.0]
-    rc += map(_util.rad2deg, data[:3])
+    rc += list(map(_util.rad2deg, data[:3]))
     return rc
 
   def getLinkbot(self, addr):
@@ -457,6 +495,12 @@ class Linkbot:
     while self.isMoving():
       time.sleep(0.1)
 
+  def _pairParent(self):
+    buf = bytearray([barobo.BaroboCtx.CMD_PAIRPARENT, 5])
+    buf += bytearray(struct.pack('!H', self.baroboCtx.zigbeeAddr))
+    buf += bytearray([0x00])
+    self.__transactMessage(buf)
+
   def ping(self, numbytes=4):
     import random
     now = time.time()
@@ -695,7 +739,7 @@ class Linkbot:
       states += [0]*(4-len(states))
     if len(speeds) < 4:
       speeds += [0.0]*(4-len(speeds))
-    speeds = map(_util.deg2rad, speeds)
+    speeds = list(map(_util.deg2rad, speeds))
     buf = bytearray([barobo.BaroboCtx.CMD_SETMOTORSTATES, 23])
     buf += bytearray(states)
     buf += bytearray(struct.pack('<4f', speeds[0], speeds[1], speeds[2], speeds[3]))
